﻿using Isopoh.Cryptography.Argon2;

namespace QuickDish.Core;

internal class User
{
    public int Id { get; set; }
    public string Username { get; set; }
    private string PasswordHash;

    public User(int id, string username, string passwordHash)
    {
        if (id <= 0)
            throw new ArgumentOutOfRangeException("User Id must be positiv", nameof(id));

        if (string.IsNullOrWhiteSpace(username))
            throw new ArgumentException("Username can't be empty", nameof(username));

        if (string.IsNullOrWhiteSpace(passwordHash))
            throw new ArgumentException("Password hash can't be empty", nameof(passwordHash));

        Id = id;
        Username = username;
        PasswordHash = passwordHash;
    }

    public bool VerifyPassword(string password)
    {
        return Argon2.Verify(PasswordHash, password);
    }

    public void SetPassword(string password)
    {
        if (string.IsNullOrEmpty(password))
            throw new ArgumentException("Password can't be empty", nameof(password));

        PasswordHash = Argon2.Hash(password);
    }
}
